Text Models
===============
.. image:: https://github.com/INGEOTEC/text_models/actions/workflows/test.yaml/badge.svg
	   :target: https://github.com/INGEOTEC/text_models/actions/workflows/test.yaml

.. image:: https://badge.fury.io/py/text-models.svg
	  :target: https://badge.fury.io/py/text-models

.. image:: https://coveralls.io/repos/github/INGEOTEC/text_models/badge.svg?branch=develop
	  :target: https://coveralls.io/github/INGEOTEC/text_models?branch=develop

.. image:: https://dev.azure.com/conda-forge/feedstock-builds/_apis/build/status/text_models-feedstock?branchName=main
	  :target: https://dev.azure.com/conda-forge/feedstock-builds/_build/latest?definitionId=16894&branchName=main

.. image:: https://img.shields.io/conda/vn/conda-forge/text_models.svg
	  :target: https://anaconda.org/conda-forge/text_models

.. image:: https://img.shields.io/conda/pn/conda-forge/text_models.svg
	  :target: https://anaconda.org/conda-forge/text_models

.. image:: https://readthedocs.org/projects/text-models/badge/?version=latest
      :target: https://text-models.readthedocs.io/en/latest/?badge=latest
      :alt: Documentation Status

.. image:: https://colab.research.google.com/assets/colab-badge.svg
	:target: https://colab.research.google.com/github/INGEOTEC/text_models/blob/master/docs/Quickstart.ipynb	  		    		       


Twitter is perhaps the social media more amenable for research. 
It requires only a few steps to obtain information, and there are 
plenty of libraries that can help in this regard. Nonetheless, 
knowing whether a particular event is expressed on Twitter is a 
challenging task that requires a considerable collection of tweets. 
This library aims to facilitate, to a researcher interested, the process 
of mining events on Twitter by opening a collection of processed 
information taken from Twitter since December 2015. The events could be 
related to natural disasters, health issues, and people's mobility, 
among other studies that can be pursued with the library proposed. 
In summary, the Python library retrieves a plethora of information in 
terms of frequencies by day of words and bi-grams of words for Arabic, 
English, Spanish, and Russian languages. As well as mobility information 
related to the number of travels among locations for more than 200 countries or territories.

The documentation is on `readthedocs <https://text_models.readthedocs.io>`_.
